pub struct ClientCommand {
pub command: ClientCommandContents,
pub game: Cow<'static, str>,
}Expand description
A client to server (game to Neuro) message.
Fields
command: ClientCommandContentsThe command itself.
game: Cow<'static, str>The game name. This is used to identify the game. It should always be the same and should not change. You should use the game’s display name, including any spaces and symbols (e.g. "Buckshot Roulette"). The server will not include this field.